@@ -1,168 +1,13 @@
 package HTML::Widgets::NavMenu;
-$HTML::Widgets::NavMenu::VERSION = '1.0902';
+$HTML::Widgets::NavMenu::VERSION = '1.1000';
 use strict;
 use warnings;
 
-use 5.012;
-
-package HTML::Widgets::NavMenu::Error;
-$HTML::Widgets::NavMenu::Error::VERSION = '1.0902';
-use parent "HTML::Widgets::NavMenu::Object";
-
-package HTML::Widgets::NavMenu::Error::Redirect;
-$HTML::Widgets::NavMenu::Error::Redirect::VERSION = '1.0902';
-use strict;
-use vars qw(@ISA);
-@ISA = ("HTML::Widgets::NavMenu::Error");
-
-sub CGIpm_perform_redirect
-{
-    my $self = shift;
-
-    my $cgi = shift;
-
-    print $cgi->redirect( $cgi->script_name() . $self->{-redirect_path} );
-    exit;
-}
-
-package HTML::Widgets::NavMenu::NodeDescription;
-$HTML::Widgets::NavMenu::NodeDescription::VERSION = '1.0902';
-use strict;
-
-use parent qw(HTML::Widgets::NavMenu::Object);
-
-__PACKAGE__->mk_acc_ref( [qw(host host_url title label direct_url url_type)] );
-
-sub _init
-{
-    my ( $self, $args ) = @_;
-
-    while ( my ( $k, $v ) = each(%$args) )
-    {
-        $self->$k($v);
-    }
-
-    return 0;
-}
-
-1;
-
-package HTML::Widgets::NavMenu::LeadingPath::Component;
-$HTML::Widgets::NavMenu::LeadingPath::Component::VERSION = '1.0902';
-use vars qw(@ISA);
-
-@ISA = (qw(HTML::Widgets::NavMenu::NodeDescription));
-
-package HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive;
-$HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive::VERSION = '1.0902';
-use parent 'HTML::Widgets::NavMenu::Iterator::Base';
-
-__PACKAGE__->mk_acc_ref(
-    [
-        qw(
-            _item_found
-            _leading_path_coords
-            _ret_coords
-            _temp_coords
-            _tree
-        )
-    ]
-);
-
-sub _init
-{
-    my $self = shift;
-    my $args = shift;
-
-    $self->SUPER::_init($args);
-
-    $self->_tree( $args->{'tree'} );
-
-    $self->_item_found(0);
-
-    return 0;
-}
-
-sub get_initial_node
-{
-    my $self = shift;
-
-    return $self->_tree;
-}
-
-sub item_matches
-{
-    my $self     = shift;
-    my $item     = $self->top();
-    my $url      = $item->_node()->url();
-    my $nav_menu = $self->nav_menu();
-    return (   ( $item->_accum_state()->{'host'} eq $nav_menu->current_host() )
-            && ( defined($url) && ( $url eq $nav_menu->path_info() ) ) );
-}
-
-sub does_item_expand
-{
-    my $self = shift;
-    my $item = $self->top();
-    return $item->_node()->capture_expanded();
-}
-
-sub node_start
-{
-    my $self = shift;
-
-    if ( $self->item_matches() )
-    {
-        my @coords = @{ $self->get_coords() };
-        $self->_ret_coords( [@coords] );
-        $self->_temp_coords( [ @coords, (-1) ] );
-        $self->top()->_node()->mark_as_current();
-        $self->_item_found(1);
-    }
-    elsif ( $self->does_item_expand() )
-    {
-        my @coords = @{ $self->get_coords() };
-        $self->_leading_path_coords( [@coords] );
-    }
-}
-
-sub node_end
-{
-    my $self = shift;
-    if ( $self->_item_found() )
-    {
-        # Skip the first node, because the coords refer
-        # to the nodes below it.
-        my $idx = pop( @{ $self->_temp_coords() } );
-        if ( $idx >= 0 )
-        {
-            my $node = $self->top()->_node();
-            $node->update_based_on_sub( $node->get_nth_sub($idx) );
-        }
-    }
-}
-
-sub node_should_recurse
-{
-    my $self = shift;
-    return ( !$self->_item_found() );
-}
-
-sub get_final_coords
-{
-    my $self = shift;
-
-    return $self->_ret_coords();
-}
-
-sub _get_leading_path_coords
-{
-    my $self = shift;
-
-    return ( $self->_ret_coords() || $self->_leading_path_coords() );
-}
-
-package HTML::Widgets::NavMenu;
+use HTML::Widgets::NavMenu::Error                        ();
+use HTML::Widgets::NavMenu::Error::Redirect              ();
+use HTML::Widgets::NavMenu::NodeDescription              ();
+use HTML::Widgets::NavMenu::LeadingPath::Component       ();
+use HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive ();
 
 use parent 'HTML::Widgets::NavMenu::Object';
 
@@ -867,7 +712,7 @@ HTML::Widgets::NavMenu - A Perl Module for Generating HTML Navigation Menus
 
 =head1 VERSION
 
-version 1.0902
+version 1.1000
 
 =head1 SYNOPSIS
 
@@ -917,8 +762,8 @@ track of navigation links ("Next", "Prev", "Up", etc.) You can start from the
 example above and see more examples in the tests, in the C<examples/>
 directory of the HTML-Widgets-NavMenu tarball, and complete working sites
 in the version control repositories at
-L<https://bitbucket.org/shlomif/shlomi-fish-homepage>
-and L<https://bitbucket.org/shlomif/perl-begin/>.
+L<https://www.shlomifish.org/meta/site-source/>
+and L<https://perl-begin.org/source/> .
 
 =head1 USAGE
 
